@@ -78,7 +78,6 @@ print.lm.design <-function(x, ...){
     ## printing x with the lm method
     NextMethod(x, ...)
     
-    stats::print.lm(x, ...)
     if (!is.null(x$WholePlotEffects)){
        cat("WARNING: This is a split plot design, whole plot effects may have larger variance!\n")
        cat("         p-values for whole plot effects may be misleadingly low!\n")
@@ -89,5 +88,5 @@ print.lm.design <-function(x, ...){
 
 coef.lm.design <- function(object, ...){
    class(object) <- c("aov", class(object))
-   stats::coef(object, ...)
+   coef(object, ...)
    }
\ No newline at end of file
